@@ -3,17 +3,25 @@ class Reminder:
         """Represents base reminder object
 
         :param method:
-                method of the reminder. Possible values: email or popup
+                Method of the reminder. Possible values: email or popup
         :param minutes_before_start:
-                minutes before reminder
+                Minutes before reminder
         """
         self.method = method
         self.minutes_before_start = minutes_before_start
 
     def __eq__(self, other):
-        return isinstance(other, Reminder) \
-               and self.method == other.method \
-               and self.minutes_before_start == other.minutes_before_start
+        return (
+                isinstance(other, Reminder)
+                and self.method == other.method
+                and self.minutes_before_start == other.minutes_before_start
+        )
+
+    def __str__(self):
+        return '{} - minutes_before_start:{}'.format(self.__class__.__name__, self.minutes_before_start)
+
+    def __repr__(self):
+        return '<{}>'.format(self.__str__())
 
 
 class EmailReminder(Reminder):
@@ -21,7 +29,7 @@ class EmailReminder(Reminder):
         """Represents email reminder object
 
         :param minutes_before_start:
-                minutes before reminder
+                Minutes before reminder
         """
         super().__init__('email', minutes_before_start)
 
@@ -31,6 +39,6 @@ class PopupReminder(Reminder):
         """Represents popup reminder object
 
         :param minutes_before_start:
-                minutes before reminder
+                Minutes before reminder
         """
         super().__init__('popup', minutes_before_start)
